Body

Enum Body 

pub enum Body {
    None,
    Some(Vec<u8>),
    Multipart(Vec<MultipartPart>),
    Err(Error),
}
Type of body detected in the request.

This is not detected from the request method, but rather from the presence (and values) of the content-length and content-type headers.

Variants



None

The request has no content-length header.



Some(Vec<u8>)

The request has a content-length header, but the content-type is something other than multipart/form-data.



Multipart(Vec<MultipartPart>)

The request has a content-length header, and the content-type is multipart/form-data. This will contain a vector of successfully-parsed body parts.



Err(Error)

There was an error at some point in the process of determining the type of or reading/parsing the body.